#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_REPEAT_LOWER_HALF_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_REPEAT_LOWER_HALF_HPP_INCLUDED

#include <boost/simd/swar/include/functions/repeat_lower_half.hpp>

#endif
